@@ -44,7 +44,7 @@
  *
  * requestobject.c 
  *
- * $Id: requestobject.c,v 1.7 2001/01/20 03:11:24 gtrubetskoy Exp $
+ * $Id: requestobject.c,v 1.8 2001/04/07 05:43:21 gtrubetskoy Exp $
  *
  */
 
@@ -835,7 +835,7 @@ static struct memberlist request_memberlist[] = {
     {"read_body",          T_INT,       OFF(read_body),            RO},
     {"read_chunked",       T_INT,       OFF(read_chunked),         RO},
     {"content_type",       T_STRING,    OFF(content_type)            },
-    {"_content_type_set",  T_INT,       NULL,                      RO},
+    {"_content_type_set",  T_INT,       0,                         RO},
     {"handler",            T_STRING,    OFF(handler),              RO},
     {"content_encoding",   T_STRING,    OFF(content_encoding),     RO},
     {"content_language",   T_STRING,    OFF(content_language),     RO},
